@@ -40,10 +40,6 @@ public:
     FilterProtocol( const QByteArray & protocol, const QByteArray &pool, const QByteArray &app );
 
     void get( const QUrl &url ) override;
-#if 0
-    virtual void put( const QUrl &url, int _mode, KIO::JobFlags _flags );
-    virtual void setSubURL(const QUrl &url);
-#endif
 
 private:
     QUrl subURL;
