@@ -557,10 +557,6 @@ void fishProtocol::writeChild(const char *buf, KIO::fileoffset_t len) {
 #else
 void fishProtocol::writeChild(const QByteArray &buf, KIO::fileoffset_t len) {
     if (outBufPos >= 0 && outBuf.size()) {
-#endif
-#if 0
-        QString debug = QString::fromLatin1(outBuf,outBufLen);
-        if (len > 0) myDebug( << "write request while old one is pending, throwing away input (" << outBufLen << "," << outBufPos << "," << debug.left(10) << "...)");
 #endif
         return;
     }
@@ -1688,7 +1684,6 @@ void fishProtocol::special( const QByteArray &data ){
         {
             QUrl u;
             QString command;
-            QString tempfile;
             stream >> u;
             stream >> command;
             myDebug( << "@@@@@@@@@ exec " << u << " " << command);
