@@ -54,7 +54,7 @@ bool RecentDocuments::rewriteUrl(const QUrl& url, QUrl& newUrl)
     if (isRootUrl(url)) {
         return false;
     } else {
-        QString desktopFilePath = QString("%1/%2.desktop").arg(KRecentDocument::recentDocumentDirectory()).arg(url.path());
+        const QString desktopFilePath = QString("%1/%2.desktop").arg(KRecentDocument::recentDocumentDirectory(), url.path());
         if (KDesktopFile::isDesktopFile(desktopFilePath)) {
             KDesktopFile file(desktopFilePath);
             if (file.hasLinkType())
