@@ -27,9 +27,9 @@ class QImageReader;
 namespace IcoUtils
 {
 
-    bool loadIcoImageFromExe(QIODevice * inputDevice, QImage &image, int needWidth=512, int needHeight=512, const qint32 iconNumber=0);
-    bool loadIcoImageFromExe(const QString &inputPath, QImage &image, int needWidth=512, int needHeight=512, const qint32 iconNumber=0);
-    bool loadIcoImageFromExe(const QString &inputFileName, QIODevice *outputDevice, const qint32 iconNumber);
+    bool loadIcoImageFromExe(QIODevice * inputDevice, QImage &image, int needWidth=512, int needHeight=512);
+    bool loadIcoImageFromExe(const QString &inputPath, QImage &image, int needWidth=512, int needHeight=512);
+    bool loadIcoImageFromExe(const QString &inputFileName, QIODevice *outputDevice);
 
     bool loadIcoImage(QIODevice * inputDevice, QImage &image, int needWidth=512, int needHeight=512);
     bool loadIcoImage(const QString &inputFileName, QImage &image, int needWidth=512, int needHeight=512);
