@@ -42,8 +42,3 @@ bool ImageCreator::create(const QString &path, int, int, QImage &img)
         img = img.convertToFormat(img.hasAlphaChannel() ? QImage::Format_ARGB32 : QImage::Format_RGB32);
     return true;
 }
-
-ThumbCreator::Flags ImageCreator::flags() const
-{
-    return None;
-}
